@@ -4,8 +4,8 @@
 # ibus-anthy - The Anthy engine for IBus
 #
 # Copyright (c) 2007-2008 Peng Huang <shawn.p.huang@gmail.com>
-# Copyright (c) 2010-2013 Takao Fujiwara <takao.fujiwara1@gmail.com>
-# Copyright (c) 2007-2013 Red Hat, Inc.
+# Copyright (c) 2010-2016 Takao Fujiwara <takao.fujiwara1@gmail.com>
+# Copyright (c) 2007-2016 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +25,6 @@ PKGDATADIR = '/usr/share/ibus-anthy'
 LIBEXECDIR = '/usr/libexec'
 LOCALEDIR = '/usr/share/locale'
 LAYOUT = 'jp'
-SYMBOL_CHAR = unichr(0x3042)
+SYMBOL_CHAR = chr(0x3042)
 ICON_PREFERENCE = 'preferences-desktop'
 DEBUG = False
